==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1ManagedFieldsEntryBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1ManagedFieldsEntryBuilder extends V1ManagedFieldsEntryFluentImpl<V1ManagedFieldsEntryBuilder> implements VisitableBuilder<V1ManagedFieldsEntry,V1ManagedFieldsEntryBuilder>{

    V1ManagedFieldsEntryFluent<?> fluent;
    Boolean validationEnabled;

    public V1ManagedFieldsEntryBuilder(){
            this(true);
    }
    public V1ManagedFieldsEntryBuilder(Boolean validationEnabled){
            this(new V1ManagedFieldsEntry(), validationEnabled);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent){
            this(fluent, true);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1ManagedFieldsEntry(), validationEnabled);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent,V1ManagedFieldsEntry instance){
            this(fluent, instance, true);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent,V1ManagedFieldsEntry instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion());

            fluent.withFields(instance.getFields());

            fluent.withManager(instance.getManager());

            fluent.withOperation(instance.getOperation());

            fluent.withTime(instance.getTime());

            this.validationEnabled = validationEnabled; 
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntry instance){
            this(instance,true);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntry instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion());

            this.withFields(instance.getFields());

            this.withManager(instance.getManager());

            this.withOperation(instance.getOperation());

            this.withTime(instance.getTime());

            this.validationEnabled = validationEnabled; 
    }

    public V1ManagedFieldsEntry build(){
            V1ManagedFieldsEntry buildable = new V1ManagedFieldsEntry();
            buildable.setApiVersion(fluent.getApiVersion());
            buildable.setFields(fluent.getFields());
            buildable.setManager(fluent.getManager());
            buildable.setOperation(fluent.getOperation());
            buildable.setTime(fluent.getTime());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ManagedFieldsEntryBuilder that = (V1ManagedFieldsEntryBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> client-java-api-8.0.0-sources.jar: io/kubernetes/client/openapi/models/V1ManagedFieldsEntryBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1ManagedFieldsEntryBuilder extends V1ManagedFieldsEntryFluentImpl<V1ManagedFieldsEntryBuilder> implements VisitableBuilder<V1ManagedFieldsEntry,V1ManagedFieldsEntryBuilder>{

    V1ManagedFieldsEntryFluent<?> fluent;
    Boolean validationEnabled;

    public V1ManagedFieldsEntryBuilder(){
            this(true);
    }
    public V1ManagedFieldsEntryBuilder(Boolean validationEnabled){
            this(new V1ManagedFieldsEntry(), validationEnabled);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent){
            this(fluent, true);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1ManagedFieldsEntry(), validationEnabled);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent,V1ManagedFieldsEntry instance){
            this(fluent, instance, true);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntryFluent<?> fluent,V1ManagedFieldsEntry instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion());

            fluent.withFieldsType(instance.getFieldsType());

            fluent.withFieldsV1(instance.getFieldsV1());

            fluent.withManager(instance.getManager());

            fluent.withOperation(instance.getOperation());

            fluent.withTime(instance.getTime());

            this.validationEnabled = validationEnabled; 
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntry instance){
            this(instance,true);
    }
    public V1ManagedFieldsEntryBuilder(V1ManagedFieldsEntry instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion());

            this.withFieldsType(instance.getFieldsType());

            this.withFieldsV1(instance.getFieldsV1());

            this.withManager(instance.getManager());

            this.withOperation(instance.getOperation());

            this.withTime(instance.getTime());

            this.validationEnabled = validationEnabled; 
    }

    public V1ManagedFieldsEntry build(){
            V1ManagedFieldsEntry buildable = new V1ManagedFieldsEntry();
            buildable.setApiVersion(fluent.getApiVersion());
            buildable.setFieldsType(fluent.getFieldsType());
            buildable.setFieldsV1(fluent.getFieldsV1());
            buildable.setManager(fluent.getManager());
            buildable.setOperation(fluent.getOperation());
            buildable.setTime(fluent.getTime());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ManagedFieldsEntryBuilder that = (V1ManagedFieldsEntryBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
